darkhistory.electrons.elec\_cooling.get\_elec\_cooling\_tf
==========================================================

.. currentmodule:: darkhistory.electrons.elec_cooling

.. autofunction:: get_elec_cooling_tf